@@ -120,11 +120,6 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
-    # Create the log file, and set some rights on it in order to prevent
-    # unwanted access
-    open(log_path, 'a').close()
-    os.chmod(log_path, 0o640)
-
     config.set('defaults', 'forks', str(min(
         multiprocessing.cpu_count() * 4, 100)))
     config.set('defaults', 'timeout', '30')
@@ -135,11 +130,6 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
                '~/.ansible/fact_cache')
-    # NOTE(mwhahaha): only gather the bare minimum facts because this has
-    # direct impact on how fast ansible can go.
-    config.set('defaults', 'gather_subset', '!all,min')
-    # NOTE(mwhahaha): this significantly affects performation per ansible#73654
-    config.set('defaults', 'inject_facts_as_vars', 'false')
 
     # Set the pull interval to lower CPU overhead
     config.set('defaults', 'internal_poll_interval', '0.01')
@@ -266,7 +256,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if (isinstance(self._inventory, six.string_types) and
                 os.path.exists(self._inventory)):
             return self._inventory
-        elif not isinstance(self._inventory, six.string_types):
+        if not isinstance(self._inventory, six.string_types):
             self._inventory = yaml.safe_dump(self._inventory)
 
         path = os.path.join(self.work_dir, 'inventory.yaml')
@@ -291,7 +281,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if (isinstance(self._playbook, six.string_types) and
                 os.path.exists(self._playbook)):
             return self._playbook
-        elif not isinstance(self._playbook, six.string_types):
+        if not isinstance(self._playbook, six.string_types):
             self._playbook = yaml.safe_dump(self._playbook)
 
         path = os.path.join(self.work_dir, self.playbook_name)
@@ -426,9 +416,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
             if not isinstance(self.extra_env_variables, dict):
                 msg = "extra_env_variables must be a dict"
                 return actions.Result(error=msg)
-            else:
-                for key, value in self.extra_env_variables.items():
-                    self.extra_env_variables[key] = six.text_type(value)
+            for key, value in self.extra_env_variables.items():
+                self.extra_env_variables[key] = six.text_type(value)
 
         if self.gather_facts:
             command.extend(['--gather-facts', self.gather_facts])
