@@ -110,7 +110,9 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
                       (image, blob_path))
 
     try:
-        with open(blob_path, 'wb') as f:
+        fd = os.open(blob_path, os.O_WRONLY | os.O_CREAT)
+        os.fchmod(fd, 0o0644)
+        with open(fd, 'wb') as f:
             count = 0
             for chunk in layer_stream:
                 count += 1
@@ -327,8 +329,8 @@ def parse_type_map_file(type_map_path):
     content_type = None
     type_map = {}
     with open(type_map_path, 'r') as f:
-        for l in f:
-            line = l[:-1]
+        for x in f:
+            line = x[:-1]
             if not line:
                 if uri and content_type:
                     type_map[content_type] = uri
