@@ -115,17 +115,15 @@ def set_neutron_driver(pd, mapping_args):
     :param pd: Parameter defaults from the environment
     :param mapping_args: Dict to set neutron_driver value on
     """
-    if mapping_args.get('neutron_driver'):
-        return
     if not pd or 'NeutronMechanismDrivers' not in pd:
         # we should set default neutron driver
         mapping_args['neutron_driver'] = 'ovn'
+        return
+    nmd = pd['NeutronMechanismDrivers']
+    if 'ovn' in nmd:
+        mapping_args['neutron_driver'] = 'ovn'
     else:
-        nmd = pd['NeutronMechanismDrivers']
-        if 'ovn' in nmd:
-            mapping_args['neutron_driver'] = 'ovn'
-        else:
-            mapping_args['neutron_driver'] = 'other'
+        mapping_args['neutron_driver'] = 'other'
 
 
 def container_images_prepare_multi(environment, roles_data, dry_run=False,
@@ -551,7 +549,7 @@ class KollaImageBuilder(base.BaseImageManager):
             raise subprocess.CalledProcessError(process.returncode, cmd, err)
 
         if template_only:
-            self.logger.info('Running %s' % ' '.join(cmd_deps))
+            self.logger.info('Running %s', ' '.join(cmd_deps))
             env = os.environ.copy()
             process = subprocess.Popen(cmd_deps, env=env,
                                        stdout=subprocess.PIPE,
