@@ -131,9 +131,8 @@ class Config(object):
                     # If no step is defined, it will be executed for all
                     # steps if strict is false
                     return True
-                else:
-                    # We only want the task with the step defined.
-                    return False
+                # We only want the task with the step defined.
+                return False
             if not isinstance(whenexpr, list):
                 whenexpr = [whenexpr]
 
@@ -148,8 +147,7 @@ class Config(object):
             if steps_found:
                 if str(step) in steps_found:
                     return True
-                else:
-                    return False
+                return False
 
             # No step found
             if strict:
@@ -179,12 +177,12 @@ class Config(object):
 
     def snapshot_config_dir(self, repo, commit_message):
         if repo.is_dirty(untracked_files=True):
-            self.log.info('Snapshotting {}'.format(repo.working_dir))
+            self.log.info('Snapshotting %s', repo.working_dir)
             # Use repo.git.add directly as repo.index.add defaults to forcing
             # commit of ignored files, which we don't want.
             repo.git.add('.')
             commit = repo.index.commit(commit_message)
-            self.log.info('Created commit {}'.format(commit.hexsha))
+            self.log.info('Created commit %s', commit.hexsha)
         else:
             self.log.info('No changes to commit')
 
@@ -201,8 +199,8 @@ class Config(object):
         # Create config directory
         if os.path.exists(config_dir) and preserve_config_dir is False:
             try:
-                self.log.info("Directory %s already exists, removing"
-                              % config_dir)
+                self.log.info("Directory %s already exists, removing",
+                              config_dir)
                 shutil.rmtree(config_dir)
             except OSError as e:
                 message = 'Failed to remove: %s, error: %s' % (config_dir,
@@ -220,8 +218,8 @@ class Config(object):
         try:
             yaml.safe_load(template_data)
         except (yaml.scanner.ScannerError, yaml.YAMLError) as e:
-            self.log.error("Config for file {} contains invalid yaml, got "
-                           "error {}".format(yaml_file, e))
+            self.log.error("Config for file %s contains invalid yaml, got "
+                           "error %s", yaml_file, e)
             raise e
 
     def render_network_config(self, config_dir):
@@ -258,7 +256,7 @@ class Config(object):
                 if config in constants.EXTERNAL_TASKS:
                     # external tasks are collected globally, not per-role
                     continue
-                elif config == 'step_config':
+                if config == 'step_config':
                     filepath = os.path.join(role_path, 'step_config.pp')
                     with self._open_file(filepath) as step_config:
                         step_config.write(role[config])
@@ -427,7 +425,7 @@ class Config(object):
                     []).append(config_dict)
             except KeyError:
                 self.log.warning('Server with id %s is ignored from config '
-                                 '(may be blacklisted)' % server_id)
+                                 '(may be blacklisted)', server_id)
                 # continue the loop as this server_id is probably excluded
                 continue
             except Exception as err:
@@ -436,9 +434,6 @@ class Config(object):
                 raise Exception(err_msg)
 
             role = self.get_role_from_server_id(stack, server_id)
-            server_pre_network = server_deployment_names.setdefault(
-                server_names[server_id], {}).setdefault(
-                'pre_network', [])
             server_pre_deployments = server_deployment_names.setdefault(
                 server_names[server_id], {}).setdefault(
                 'pre_deployments', [])
@@ -456,9 +451,6 @@ class Config(object):
                     'PostConfig' in deployment.physical_resource_id:
                 if deployment_name not in server_post_deployments:
                     server_post_deployments.append(deployment_name)
-            elif 'PreNetworkConfig' in deployment.physical_resource_id:
-                if deployment_name not in server_pre_network:
-                    server_pre_network.append(deployment_name)
             else:
                 if deployment_name not in server_pre_deployments:
                     server_pre_deployments.append(deployment_name)
@@ -551,8 +543,6 @@ class Config(object):
                     role_host_vars[role][server],
                     default_flow_style=False) if role_host_vars else None)
 
-            pre_network = server_deployment_names.get(
-                server, {}).get('pre_network', [])
             pre_deployments = server_deployment_names.get(
                 server, {}).get('pre_deployments', [])
             post_deployments = server_deployment_names.get(
@@ -561,7 +551,6 @@ class Config(object):
             with open(host_var_server_path, 'w') as f:
                 template_data = host_var_server_template.render(
                     role=role,
-                    pre_network=pre_network,
                     pre_deployments=pre_deployments,
                     post_deployments=post_deployments,
                     ansible_host_vars=ansible_host_vars)
@@ -576,7 +565,7 @@ class Config(object):
             os.path.join(config_dir, 'deployments.yaml'))
 
         self.log.info("The TripleO configuration has been successfully "
-                      "generated into: %s" % config_dir)
+                      "generated into: %s", config_dir)
         return config_dir
 
     def download_config(self, name, config_dir, config_type=None,
@@ -591,7 +580,7 @@ class Config(object):
         self._mkdir(config_dir)
         git_repo = self.initialize_git_repo(config_dir)
         self.log.info("Generating configuration under the directory: "
-                      "%s" % config_dir)
+                      "%s", config_dir)
         self.write_config(stack, name, config_dir, config_type)
         self.snapshot_config_dir(git_repo, commit_message)
         return config_dir
@@ -600,23 +589,25 @@ class Config(object):
 def get_overcloud_config(swift, heat,
                          container=constants.DEFAULT_CONTAINER_NAME,
                          container_config=constants.CONFIG_CONTAINER_NAME,
-                         config_dir=None, config_type=None):
+                         config_dir=None, config_type=None,
+                         preserve_config=False):
     if not config_dir:
         config_dir = tempfile.mkdtemp(prefix='tripleo-',
                                       suffix='-config')
 
-    # Since the config-download directory is now a git repo, first download
-    # the existing config container if it exists so we can reuse the
-    # existing git repo.
-    try:
-        swiftutils.download_container(swift, container_config,
-                                      config_dir)
-        # Delete the existing container before we re-upload, otherwise
-        # files may not be fully overwritten.
-        swiftutils.delete_container(swift, container_config)
-    except swiftexceptions.ClientException as err:
-        if err.http_status != 404:
-            raise
+    if swift:
+        # Since the config-download directory is now a git repo, first download
+        # the existing config container if it exists so we can reuse the
+        # existing git repo.
+        try:
+            swiftutils.download_container(swift, container_config,
+                                          config_dir)
+            # Delete the existing container before we re-upload, otherwise
+            # files may not be fully overwritten.
+            swiftutils.delete_container(swift, container_config)
+        except swiftexceptions.ClientException as err:
+            if err.http_status != 404:
+                raise
 
     # Delete downloaded tarball as it will be recreated later and we don't
     # want to include the old tarball in the new tarball.
@@ -633,19 +624,21 @@ def get_overcloud_config(swift, heat,
                                          preserve_config_dir=True,
                                          commit_message=message)
 
-    with tempfile.NamedTemporaryFile() as tmp_tarball:
-        tarball.create_tarball(config_path, tmp_tarball.name,
-                               excludes=['.tox', '*.pyc', '*.pyo'])
-        tarball.tarball_extract_to_swift_container(
-            swift,
-            tmp_tarball.name,
-            container_config)
-        # Also upload the tarball to the container for use by export later
-        with open(tmp_tarball.name, 'rb') as t:
-            swift.put_object(container_config,
-                             '%s.tar.gz' % container_config, t)
-    if os.path.exists(config_path):
-        shutil.rmtree(config_path)
+    if swift:
+        with tempfile.NamedTemporaryFile() as tmp_tarball:
+            tarball.create_tarball(config_path, tmp_tarball.name,
+                                   excludes=['.tox', '*.pyc', '*.pyo'])
+            tarball.tarball_extract_to_swift_container(
+                swift,
+                tmp_tarball.name,
+                container_config)
+            # Also upload the tarball to the container for use by export later
+            with open(tmp_tarball.name, 'rb') as t:
+                swift.put_object(container_config,
+                                 '%s.tar.gz' % container_config, t)
+    if not preserve_config:
+        if os.path.exists(config_path):
+            shutil.rmtree(config_path)
 
 
 def download_overcloud_config(swift,
