@@ -74,14 +74,14 @@ class DriverInfo(object):
     def convert_key(self, key):
         if key in self._mapping:
             return self._mapping[key]
-        elif key in self._deprecated_mapping:
+        if key in self._deprecated_mapping:
             real = self._deprecated_mapping[key]
             LOG.warning('Key %s is deprecated, please use %s',
                         key, real)
             return real
-        elif key.startswith(self._prefix):
+        if key.startswith(self._prefix):
             return key
-        elif key != 'pm_type' and key.startswith('pm_'):
+        if key != 'pm_type' and key.startswith('pm_'):
             LOG.warning('Key %s is not supported and will not be passed',
                         key)
         else:
@@ -395,8 +395,9 @@ def register_ironic_node(node, client):
     ironic_node = client.node.create(**create_map)
 
     for port in node.get('ports', []):
-        LOG.debug('Creating Bare Metal port for node: %s, with properties: %s.'
-                  % (ironic_node.uuid, port))
+        LOG.debug(
+            'Creating Bare Metal port for node: %s, with properties: %s.',
+            ironic_node.uuid, port)
         client.port.create(
             address=port.get('address'),
             physical_network=port.get('physical_network', 'ctlplane'),
@@ -452,7 +453,7 @@ def _get_node_id(node, handler, node_map):
         raise exception.InvalidNode('Several candidates found for the same '
                                     'node data: %s' % candidates,
                                     node=node)
-    elif candidates:
+    if candidates:
         return list(candidates)[0]
 
 
@@ -527,10 +528,10 @@ def _clean_up_extra_nodes(seen, client, remove=False):
     extra_nodes = all_nodes - {n.uuid for n in seen}
     for node in extra_nodes:
         if remove:
-            LOG.debug('Removing extra registered node %s.' % node)
+            LOG.debug('Removing extra registered node %s.', node)
             remove_func(node)
         else:
-            LOG.debug('Extra registered node %s found.' % node)
+            LOG.debug('Extra registered node %s found.', node)
 
 
 def register_all_nodes(nodes_list, client, remove=False, glance_client=None,
@@ -721,8 +722,7 @@ def generate_hostmap(baremetal_client, compute_client):
 
     if hostmap == {}:
         return None
-    else:
-        return hostmap
+    return hostmap
 
 
 def run_nova_cell_v2_discovery():
