@@ -22,7 +22,6 @@ import requests
 import sys
 import tempfile
 import yaml
-import zlib
 
 from heatclient.common import template_utils
 from heatclient import exc as heat_exc
@@ -186,66 +185,6 @@ def build_env_paths(swift, container, plan_env):
     return env_paths, temp_env_paths
 
 
-def format_cache_key(plan_name, key_name):
-    return "__cache_{}_{}".format(plan_name, key_name)
-
-
-def cache_get(swift, plan_name, key):
-    """Retrieves the stored objects
-
-    Returns None if there are any issues or no objects found
-
-    """
-
-    try:
-        headers, body = swift.get_object(
-            constants.TRIPLEO_CACHE_CONTAINER,
-            format_cache_key(plan_name, key)
-        )
-        result = json.loads(zlib.decompress(body).decode())
-        return result
-    except swiftexceptions.ClientException:
-        # cache does not exist, ignore
-        pass
-    except ValueError:
-        # the stored json is invalid. Deleting
-        cache_delete(swift, plan_name, key)
-    return None
-
-
-def cache_set(swift, plan_name, key, contents):
-    """Stores an object
-
-    Allows the storage of jsonable objects except for None
-    Storing None equals to a cache delete.
-
-    """
-
-    if contents is None:
-        cache_delete(swift, plan_name, key)
-        return
-
-    try:
-        swift.head_container(constants.TRIPLEO_CACHE_CONTAINER)
-    except swiftexceptions.ClientException:
-        swift.put_container(constants.TRIPLEO_CACHE_CONTAINER)
-
-    swift.put_object(
-        constants.TRIPLEO_CACHE_CONTAINER,
-        format_cache_key(plan_name, key),
-        zlib.compress(json.dumps(contents).encode()))
-
-
-def cache_delete(swift, plan_name, key):
-    try:
-        swift.delete_object(
-            constants.TRIPLEO_CACHE_CONTAINER,
-            format_cache_key(plan_name, key))
-    except swiftexceptions.ClientException:
-        # cache or container does not exist. Ignore
-        pass
-
-
 def create_plan_container(swift, plan_name):
     if not pattern_validator(constants.PLAN_NAME_PATTERN, plan_name):
         message = ("The plan name must "
@@ -276,7 +215,6 @@ def update_plan_environment(swift, environments,
             if found:
                 env['environments'].remove({'path': k})
 
-    cache_delete(swift, container, "tripleo.parameters.get")
     put_env(swift, env)
     return env
 
@@ -289,8 +227,8 @@ def get_role_data(swift, container=constants.DEFAULT_CONTAINER_NAME):
             constants.OVERCLOUD_J2_ROLES_NAME)
         role_data = yaml.safe_load(j2_role_file)
     except swiftexceptions.ClientException:
-        LOG.info("No %s file found, not filtering container images by role"
-                 % constants.OVERCLOUD_J2_ROLES_NAME)
+        LOG.info("No %s file found, not filtering container images by role",
+                 constants.OVERCLOUD_J2_ROLES_NAME)
         role_data = None
     return role_data
 
@@ -396,7 +334,7 @@ def generate_passwords(swift, heat, mistral=None,
         env = get_env(swift, container)
     except swiftexceptions.ClientException as err:
         err_msg = ("Error retrieving environment for plan %s: %s" % (
-            container, err))
+            container, err))  # pylint: disable=logging-not-lazy
         LOG.exception(err_msg)
         return RuntimeError(err_msg)
 
@@ -408,28 +346,26 @@ def generate_passwords(swift, heat, mistral=None,
         # We don't modify these to avoid changing defaults
         for pw_res in constants.LEGACY_HEAT_PASSWORD_RESOURCE_NAMES:
             try:
+                res = heat.resources.get(container, pw_res)
                 param_defaults = stack_env.get('parameter_defaults', {})
-                if pw_res not in param_defaults:
-                    res = heat.resources.get(container, pw_res)
-                    param_defaults[pw_res] = res.attributes['value']
+                param_defaults[pw_res] = res.attributes['value']
             except heat_exc.HTTPNotFound:
-                LOG.debug('Heat resouce not found: %s' % pw_res)
+                LOG.debug('Heat resouce not found: %s', pw_res)
                 pass
 
     except heat_exc.HTTPNotFound:
         stack_env = None
 
-    placement_extracted = False
     try:
         # We can't rely on the existence of PlacementPassword to
         # determine if placement extraction has occured as it was added
         # in stein while the service extraction was delayed to train.
         # Inspect the endpoint map instead.
         endpoint_res = heat.resources.get(container, 'EndpointMap')
-        endpoints = endpoint_res.attributes.get('endpoint_map', None)
-        placement_extracted = endpoints and 'PlacementPublic' in endpoints
+        endpoints = endpoint_res.attributes.get('endpoint_map', {})
+        placement_extracted = 'PlacementPublic' in endpoints
     except heat_exc.HTTPNotFound:
-        pass
+        placement_extracted = False
 
     passwords = password_utils.generate_passwords(
         stack_env=stack_env,
@@ -478,7 +414,6 @@ def generate_passwords(swift, heat, mistral=None,
         LOG.exception(err_msg)
         raise RuntimeError(err_msg)
 
-    cache_delete(swift, container, "tripleo.parameters.get")
     return env['passwords']
 
 
@@ -511,7 +446,6 @@ def update_plan_rotate_fernet_keys(swift,
         LOG.exception(err_msg)
         raise RuntimeError(err_msg)
 
-    cache_delete(swift, container, "tripleo.parameters.get")
     return keys_map
 
 
