@@ -19,7 +19,6 @@ import logging
 import time
 import uuid
 
-from heatclient.common import template_utils
 from heatclient import exc as heat_exc
 from swiftclient import exceptions as swiftexceptions
 
@@ -31,68 +30,6 @@ from tripleo_common.utils import template as templates
 LOG = logging.getLogger(__name__)
 
 
-def stack_update(swift, heat, timeout,
-                 container=constants.DEFAULT_CONTAINER_NAME):
-    # get the stack. Error if doesn't exist
-    try:
-        stack = heat.stacks.get(container)
-    except heat_exc.HTTPNotFound:
-        msg = "Error retrieving stack: %s" % container
-        LOG.exception(msg)
-        raise RuntimeError(msg)
-
-    try:
-        env = plan_utils.get_env(swift, container)
-    except swiftexceptions.ClientException as err:
-        err_msg = ("Error retrieving environment for plan %s: %s" % (
-            container, err))
-        LOG.exception(err_msg)
-        raise RuntimeError(err_msg)
-
-    update_env = {
-        'parameter_defaults': {
-            'DeployIdentifier': int(time.time()),
-        },
-    }
-
-    noop_env = {
-        'resource_registry': {
-            'OS::TripleO::DeploymentSteps': 'OS::Heat::None',
-        },
-    }
-
-    for output in stack.to_dict().get('outputs', {}):
-        if output['output_key'] == 'RoleData':
-            for role in output['output_value']:
-                role_env = {
-                    "OS::TripleO::Tasks::%sPreConfig" % role:
-                    'OS::Heat::None',
-                    "OS::TripleO::Tasks::%sPostConfig" % role:
-                    'OS::Heat::None',
-                }
-                noop_env['resource_registry'].update(role_env)
-    update_env.update(noop_env)
-    template_utils.deep_update(env, update_env)
-    try:
-        plan_utils.put_env(swift, env)
-    except swiftexceptions.ClientException as err:
-        err_msg = ("Error updating environment for plan %s: %s" % (
-            container, err))
-        LOG.exception(err_msg)
-        raise RuntimeError(err_msg)
-
-    # process all plan files and create or update a stack
-    processed_data = templates.process_templates(
-        swift, heat, container
-    )
-    stack_args = processed_data.copy()
-    stack_args['timeout_mins'] = timeout
-
-    LOG.info("Performing Heat stack update")
-    LOG.info('updating stack: %s', stack.stack_name)
-    return heat.stacks.update(stack.id, **stack_args)
-
-
 def _process_params(flattened, params):
     for item in params:
         if item not in flattened['parameters']:
